@@ -110,6 +110,22 @@ from copy import deepcopy
 from datetime import datetime
 
 
+# Workaround for windows bug: getpass does not support unicode() instances
+if sys.version_info < (3,) and sys.platform.startswith('win'):
+    _getpass = getpass
+
+    def getpass(s):
+        try:
+            # First try ASCII or hope it is already a string
+            return _getpass(str(s))
+        except UnicodeEncodeError:
+            from locale import getpreferredencoding
+            try:
+                return _getpass(s.encode(getpreferredencoding()))
+            except UnicodeEncodeError:
+                return _getpass(b'Password: ')
+
+
 def format_timestamp(dt):
     if dt is None:
         return None
@@ -386,7 +402,10 @@ DEFAULT_CONFIG = {
         ['{0}', r'\0(discussion|question)\0', 'proposal'],
     ],
     'statuses': [
-        ['{0}', r'\0(invalid|duplicate|wontfix)\0', '{1}'],
+        ['{0}', r'\0((?i)invalid|duplicate|wontfix)\0', '{1}'],
+    ],
+    'components': [
+        ['{0}', r'\0component: ([^\0]+)\0', '{1}'],
     ],
 }
 
